module Adminka
  class CrudController < AdminController
    include Staff

    before_action :check_auth

    def initialize
      super
      @config = @menu[self.class::MODEL.downcase]
      @model = Object.const_get(self.class::MODEL)
    end

    def index
      @q = @model.ransack(params[:q])
      @entities = @q.result.select(select_fields('list')).page(params[:page])
    end

    def create
      @entity = @model.new(entity_params)
      return render :new unless @entity.save
      flash[:notice] = t('adminka.create')
      redirect_to @entity
    end

    def new
      @entity = @model.new
    end

    def show
      @entity = @model.select(select_fields('show')).find(params[:id])
    end

    def edit
      @entity = @model.select(select_fields('edit')).find(params[:id])
    end

    def update
      @entity = @model.find(params[:id])
      if @entity.update(entity_params)
        flash[:notice] = t('adminka.update')
        redirect_to @entity
      else
        render :edit
      end
    end

    def destroy
      @model.find(params[:id]).destroy
      flash[:notice] = t('adminka.delete')
      redirect_to adminka.send("#{@model.to_s.downcase.pluralize}_path")
    end

    private

    def entity_params
      params.require(@model.to_s.downcase.to_sym).permit(select_fields('edit'))
    end

  end
end
